| .init_helper | R Documentation |
Users typically should not need to call this function.
Create new helpers that will automatically be registered with this function
with prompt_new().
The chores addin will initialize needed helpers on-the-fly.
.init_helper(chore = NULL, .chores_chat = get_chores_chat())
chore |
The identifier for a helper prompt. By default one
of "cli", "testthat" or "roxygen",
though custom helpers can be added with |
.chores_chat |
An ellmer Chat, e.g.
|
A Helper object, which is a subclass of an ellmer chat.
# requires an API key and sets options
## Not run:
# to create a chat with claude:
.init_helper(.chores_chat = ellmer::chat_claude(model = "claude-haiku-4-5"))
# or with OpenAI's GPT-4.1-mini:
.init_helper(.chores_chat = ellmer::chat_openai(model = "gpt-4.1-mini"))
# or with Google's Gemini 3 Flash:
.init_helper(.chores_chat = ellmer::chat_google_gemini(
model = "gemini-3-flash-preview",
api_args = list(
generationConfig = list(
thinkingConfig = list(thinkingLevel = "minimal")
)
)
))
# to set OpenAI's GPT-4.1-mini as the default model powering chores, for example,
# set the following option (possibly in your .Rprofile, if you'd like
# them to persist across sessions):
options(
chores.chat = ellmer::chat_openai(model = "gpt-4.1-mini")
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.